<?php

namespace App\Service;

use App\Entity\Project;
use App\Entity\Task;
use GeoJson\GeoJson;
use Symfony\Component\Routing\Generator\UrlGeneratorInterface;
use Symfony\Component\Workflow\WorkflowInterface;

class GeoJsonManager
{

    public function __construct(
        private UrlGeneratorInterface $router,
        private WorkflowInterface $taskLifecycleStateMachine,
    ) {
    }

    private function getFullGeoJson(Task $task)
    {
        $data = json_decode($task->getGeojson(), true);
        if (isset($data['features'][0]['properties'])) {
        $data['features'][0]['properties'] = array_merge($data['features'][0]['properties'], [
            'name' => $task->getName(),
            'url' => $this->router->generate('app_task_show', ['slug' => $task->getSlug()], UrlGeneratorInterface::ABSOLUTE_URL),
            'color' => $this->taskLifecycleStateMachine->getMetadataStore()->getPlaceMetadata($task->getStatus())['color'],
        ]);
        } else {
            dump($data);
        }
        return $data;
    }

    public function generateGeoJson($entity) 
    {
        $geoJsons = [];

        if ($entity instanceof Task) {
            $task = $entity;
            $geoJsons[] = GeoJson::jsonUnserialize($this->getFullGeojson($task));
        } elseif ($entity instanceof Project) {
            $project = $entity;
            foreach ($project->getTasks() as $task) {
                $geoJsons[] = GeoJson::jsonUnserialize($this->getFullGeojson($task));
            }
        }

        return $geoJsons;
    }

}
